#
# spec file for package libkdumpfile
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Begin compatibility cruft
#

%{!?make_install:%define make_install make install DESTDIR=%{?buildroot}}

%if 0%{!?have_zstd:1}
%if 0%{?sle_version} >= 152000 || 0%{?suse_version} > 1500
%define have_zstd 1
%else
%define have_zstd 0
%endif
%endif

#
# End compatibility cruft

Name:           libkdumpfile
Version:        0.5.4
Release:        1.3
%if "%name" == "libkdumpfile"
Summary:        Kernel dump file access library
License:        GPL-2.0-or-later OR LGPL-3.0-or-later
Group:          Development/Languages/Python
%else
Summary:        Python interface for libkdumpfile
License:        GPL-2.0-or-later OR LGPL-3.0-or-later
Group:          Development/Languages/Python
%endif
URL:            https://github.com/ptesarik/libkdumpfile
Source:         %{name}-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  binutils-devel
BuildRequires:  libtool
%if %{have_zstd}
BuildRequires:  libzstd-devel
%endif
BuildRequires:  lzo-devel
BuildRequires:  pkgconfig
BuildRequires:  snappy-devel
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A library that provides an abstraction layer for reading kernel dump
core files.  It supports different kernel dump core formats, virtual
to physical translation, Xen mappings and more.

%package -n %{name}-devel
Summary:        Include files and libraries for libkdumpfile development
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libkdumpfile10 = %{version}

%description -n %{name}-devel
This package contains all necessary include files and libraries needed
to develop applications that require libkdumpfile.

%package -n libkdumpfile10
Summary:        Kernel dump file access library
Group:          System/Libraries

%description -n libkdumpfile10
A library that provides an abstraction layer for reading kernel dump
core files.  It supports different kernel dump core formats, virtual
to physical translation, Xen mappings and more.

This package contains the libkdumpfile library.

%package -n libaddrxlat3
Summary:        Address translation library used primarily by libkdumpfile
Group:          System/Libraries

%description -n libaddrxlat3
A library that provides an abstraction layer for translating addresses
between address spaces (i.e. physical vs virtual).

This package contains the libaddrxlat library.

%package -n libaddrxlat-devel
Summary:        Include files and libraries for libaddrxlat development
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libaddrxlat3 = %{version}

%description -n libaddrxlat-devel
This package contains all necessary include files and libraries needed
to develop applications that require libaddrxlat.

%prep
%setup -q
%autopatch -p1

%build
aclocal
autoreconf -fvi
%configure --disable-static --without-python
make %{?_smp_mflags}

%install
%make_install

# Do not install example code
rm -v %{?buildroot}%{_bindir}/dumpattr
rm -v %{?buildroot}%{_bindir}/listxendoms
rm -v %{?buildroot}%{_bindir}/showxlat
# Remove Libtool files
rm -v %{?buildroot}%{_libdir}/libkdumpfile.la
rm -v %{?buildroot}%{_libdir}/libaddrxlat.la

%post -n libkdumpfile10 -p /sbin/ldconfig

%post -n libaddrxlat3 -p /sbin/ldconfig

%postun -n libkdumpfile10 -p /sbin/ldconfig

%postun -n libaddrxlat3 -p /sbin/ldconfig

%files -n libkdumpfile10
%defattr(-,root,root)
%{_libdir}/libkdumpfile.so.*
%license COPYING COPYING.GPLv2 COPYING.GPLv3 COPYING.LGPLv3
%doc README.md NEWS

%files -n libkdumpfile-devel
%defattr(-,root,root)
%{_includedir}/libkdumpfile/kdumpfile.h
%{_libdir}/libkdumpfile.so
%{_libdir}/pkgconfig/libkdumpfile.pc

%files -n libaddrxlat3
%defattr(-,root,root)
%{_libdir}/libaddrxlat.so.*
%license COPYING COPYING.GPLv2 COPYING.GPLv3 COPYING.LGPLv3
%doc README.md NEWS

%files -n libaddrxlat-devel
%defattr(-,root,root)
%dir %{_includedir}/libkdumpfile
%{_includedir}/libkdumpfile/addrxlat.h
%{_libdir}/libaddrxlat.so
%{_libdir}/pkgconfig/libaddrxlat.pc

%changelog
* Sun Nov 19 2023 Petr Tesařík <petr@tesarici.cz>
- Upgrade to libkdumpfile version 0.5.4
  * Full support for 64-bit RISC-V.
  * Improve error messages (detailed OS error, optional file names)
  * Bug fixes and minor performance tweaks.
* Wed Nov  8 2023 Petr Tesařík <petr@tesarici.cz>
- Do not build Python bindings.
* Mon Nov  6 2023 Petr Tesařík <petr@tesarici.cz>
- Upgrade to libkdumpfile version 0.5.3
  * Support flattened KDUMP format.
* Mon Jul 17 2023 Petr Tesařík <petr@tesarici.cz>
- Upgrade to libkdumpfile version 0.5.2
  * Full support for 32-bit Arm.
  * ERASEINFO in the file.eraseinfo.raw attribute.
* Fri Apr 21 2023 Petr Tesařík <petr@tesarici.cz>
- Remove compatibility with SLE12 before SP3.
* Thu Apr 20 2023 Petr Tesařík <petr@tesarici.cz>
- Fix build for SLE12 (no libzstd).
- Remove pre-SLE12 compatibility.
* Wed Mar  1 2023 Martin Liška <mliska@suse.cz>
- Enable zstd compression algorithm.
* Sat Feb 25 2023 Petr Tesařík <petr@tesarici.cz>
- Build from git using an OBS service file.
* Sat Jan 21 2023 Petr Tesařík <ptesarik@suse.com>
- Upgrade to libkdumpfile version 0.5.1
  * Bitmap of all RAM in the memory.pagemap attribute.
  * Enhance the API with conversions between numeric and string PTE
    format: addrxlat_pte_format(), addrxlat_pte_format_name().
  * Improve compatibility (mawk, Python 3.12).
* Fri Aug 12 2022 Petr Tesařík <ptesarik@suse.com>
- Upgrade to libkdumpfile version 0.5.0
  * Support SADUMP file format.
  * Add kdump_open_fd() and kdump_open_fdset(). Keep KDUMP_ATTR_FILE_FD
    for (partial) backward compatibility.
  * Redesigned addrxlat callback API.
  * Support KDUMP file sets created by makedumpfile --split.
  * Zstandard compression algorithm
  * AArch64 52-bit VA
  * Address translation tuning with addrxlat.default.* and addrxlat.force.*
    attributes.
- Drop patches that are upstream:
  * libkdumpfile-live-source-Xen-DomU-type-from-sysfs.patch
* Thu Jul  7 2022 Petr Tesařík <ptesarik@suse.com>
- libkdumpfile-live-source-Xen-DomU-type-from-sysfs.patch:
  Determine live source Xen DomU type from sysfs (fixes a GCC 12
  build failure).
* Thu Nov  4 2021 Petr Tesařík <ptesarik@suse.com>
- upgrade to libkdumpfile-0.4.1
  * Support Linux on AArch64
  * Support for x86 Secure Memory Encryption
  * Clean up vmcoreinfo string API
  * Expose mmap and read cache statistics
- Drop patches that are upstream:
  * libkdumpfile-use-python-distutils.patch
  * libkdumpfile-uninstall-using-distutils.patch
  * libkdumpfile-honour-DESTDIR.patch
  * libkdumpfile-move-python-setup-command-options.patch
  * libkdumpfile-python-includedir.patch
* Fri Feb 19 2021 Petr Tesařík <ptesarik@suse.com>
- Fix build for openSUSE:Factory.
* Sun Sep 27 2020 Petr Tesařík <ptesarik@suse.com>
- Switch to Python distutils:
  * libkdumpfile-use-python-distutils.patch
  * libkdumpfile-uninstall-using-distutils.patch
  * libkdumpfile-honour-DESTDIR.patch
  * libkdumpfile-move-python-setup-command-options.patch
  * libkdumpfile-python-includedir.patch
- Merge python-libaddrxlat into python-libkdumpfile.
- Build both Python2 and Python3 packages.
* Tue Sep 22 2020 Petr Tesařík <ptesarik@suse.com>
- upgrade to libkdumpfile-0.4.0
  * 5-level paging for x86-64
  * bitmap and blob attributes
  * kASLR support for Linux kernels
  * address translation speed-ups
  * many bugfixes
- Drop fix-build-with-recent-glibc.patch (now upstream).
* Tue Apr 28 2020 Petr Tesařík <ptesarik@suse.com>
- Mark COPYING* files with %%license.
* Tue Apr  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add fix-build-with-recent-glibc.patch
* Fri Jun  9 2017 ptesarik@suse.com
- Use the correct RPM Group for Python packages.
* Mon May 15 2017 ptesarik@suse.com
- upgrade to libkdumpfile-0.3.0
  * API and ABI changed (see NEWS)
  * Address translation routines moved into `libaddrxlat` (can be
    used without a dump file).
  * Python bindings.
  * Comprehensive test suite for `libaddrxlat`.
  * Caching.
  * ...and more!
* Mon Feb  1 2016 ptesarik@suse.com
- upgrade to libkdumpfile-0.2.0
  * API and ABI changed (see NEWS)
  * differentiation of Xen dump types (attribute "xen.type")
  * support for opening dumps in Xen hypervisor mode
  * many other Xen improvements
  * fix reading LKCD dump files
* Tue Dec  8 2015 ptesarik@suse.com
- upgrade to libkdumpfile-0.1.7
  * metadata is stored as hierarchical attributes which can be enumerated
- libkdumpfile-add-EM_AARCH64.patch: Dropped (now upstream).
- libkdumpfile-remove-ARCH_PPC64LE.patch: Dropped (now upstream).
- libkdumpfile-fallback-for-old-zlib.patch: Dropped (now upstream).
* Thu Nov 26 2015 ptesarik@suse.com
- Remove autoreconf invocation (fix build on SLE10).
* Wed Nov 25 2015 ptesarik@suse.com
- Add pkg-config to BuildRequires (adds back zlib support).
- libkdumpfile-fallback-for-old-zlib.patch: Fall back to
  AC_SEARCH_LIBS if there is no pkg-config file for zlib.
* Wed Nov 25 2015 ptesarik@suse.cz
- upgrade to libkdumpfile-0.1.5
  * Improved support of Xen dumpcore files.
  * Basic support for MIPS architecture.
  * Fix support for LKCD dumps on s390x.
- Add libkdumpfile.pc pkg-config file to -devel package.
- libkdumpfile-remove-ARCH_PPC64LE.patch: Fix build on ppc64le.
* Sat Aug 22 2015 jengelh@inai.de
- Set RPM group per standard practices. Update license field to
  actual conditions. Use original source URL.
* Fri Dec  5 2014 ptesarik@suse.cz
- upgrade to libkdumpfile-0.1.4
  * Improved error reporting.
  * Support of 32-bit x86 file format.
* Fri Nov  7 2014 ptesarik@suse.cz
- upgrade to libkdumpfile-0.1.3
  * Support of z/Architecture and S390 Dump file format.
* Mon Nov  3 2014 ptesarik@suse.cz
- Do not build static libraries.
* Sun Nov  2 2014 ptesarik@suse.cz
- Fix devel package dependencies.
* Sun Nov  2 2014 ptesarik@suse.cz
- Define %%make_install if not yet defined. This allows building
  the package on very old products (SLES10).
* Sat Nov  1 2014 ptesarik@suse.cz
- libkdumpfile-add-EM_AARCH64.patch: Add definition of EM_AARCH64
  if missing.
* Fri Oct 31 2014 ptesarik@suse.cz
- Make snappy support optional (fix build on products that do not
  have that library).
* Fri Oct 31 2014 ptesarik@suse.cz
- upgrade to libkdumpfile-0.1.2
- Drop libkdumpfile-fix-kdump_phys_base.patch: Upstream.
* Wed Oct 29 2014 ptesarik@suse.cz
- libkdumpfile-fix-kdump_phys_base.patch: Fix return type of
  kdump_phys_base() in definition.
* Wed Oct 29 2014 ptesarik@suse.cz
- Initial import.
